@@ -8,7 +8,7 @@ import pkgutil
 import xin2pbn.xin2pbn as xin2pbn
 import pbn2html.pbn2html as pbn2html
 
-from lin2pbn import bbo2pbn
+from .lin2pbn import bbo2pbn
 
 import requests
 import re
